@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "transwin" "0.1.4"
+(define-package "transwin" "20250101.1013"
   "Make window/frame transparent."
   '((emacs "24.3"))
   :url "https://github.com/jcs-elpa/transwin"
-  :commit "ed0156a98b6fce94da9045bdffe369f390b70c0c"
-  :revdesc "ed0156a98b6f"
+  :commit "bcf4cc2e83ab771dcec43973106951c643637a91"
+  :revdesc "bcf4cc2e83ab"
   :keywords '("frames" "window" "transparent")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
